/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.activation.validators;

import javax.annotation.Resource;

import org.springframework.validation.Errors;
import org.springframework.validation.ValidationUtils;
import org.springframework.validation.Validator;

import se.vgregion.account.services.AccountService;
import se.vgregion.activation.domain.ActivationAccount;
import se.vgregion.activation.domain.ActivationAccountStatus;
import se.vgregion.activation.domain.ActivationCode;
import se.vgregion.activation.formbeans.PasswordFormBean;

public class AccountActivationLoginValidator implements Validator {
    @Resource
    private AccountService accountService;

    @Override
    public boolean supports(Class<?> clazz) {
        return PasswordFormBean.class.equals(clazz);
    }

    @Override
    public void validate(Object target, Errors errors) {
        PasswordFormBean form = (PasswordFormBean) target;

        ValidationUtils.rejectIfEmptyOrWhitespace(errors, "activationCode", "code.missing",
                                                  "Activation code is missing");

        if (!errors.hasErrors()) {
            ActivationAccount account = accountService.getAccount(new ActivationCode(form.getActivationCode()));
            if (account == null) {
                errors.rejectValue("activationCode", "code.illegal", "Felaktig aktiveringskod");
            } else {
                ActivationAccountStatus status = account.currentStatus();
                if (status == ActivationAccountStatus.INVALID) {
                    errors.rejectValue("activationCode", status.toString(), "Aktiveringskoden har redan använts");
                } else if (status == ActivationAccountStatus.EXPIRED) {
                    errors.rejectValue("activationCode", status.toString(), "Aktiveringskoden är för gammal");
                }
            }
        }
    }

}
